#!/usr/bin/env python
"""
 @file: AddProfile.py
  File is a part of Scribo Project
  Module implements add profile window from UI
  @author: Zaiceva Diana <zaiceva@cs.karelia.ru>
  @date: 11.12.2009
"""
import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

from ldm.Profile import *
from ldm.Account import *
from services.Dispatcher import dispatcher

from ToolbarWindow import ToolbarWindow
from StartPage import StartPage

__author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
__version__ = "$Revision: 0.1 $"
__date__ = "$Date: 2009/12/11 $"
__copyright__ = ""
__license__ = "GPLv2"


class AddProfileWindow(ToolbarWindow, StartPage):
    """
    class for draw profile window
    @version  1.0
    @author  Zaiceva Diana <zaiceva@cs.karelia.ru>
    @todo  auth_check
    """
    def __init__(self, parent=None, default=None):
        """
        initialization "add profile" window
        default = default account (for managing profile) or None (for adding profile) 
        @return
        """
        QtGui.QWidget.__init__(self, parent.centralWidget())
        self.accounts2 = []
        self.default = default
        self.create_actions()
        toolbar = self.create_toolbar()
        self.hbox_add = QtGui.QHBoxLayout()
       
        login_label = QtGui.QLabel(self.tr("Login"), self)
        login_label.setAlignment(QtCore.Qt.AlignLeft)
        pasw_label = QtGui.QLabel(self.tr("Password"), self)
        pasw_label.setAlignment(QtCore.Qt.AlignLeft)
        self.login_edit = QtGui.QLineEdit(self)
        self.pasw_edit = QtGui.QLineEdit(self)
        self.pasw_edit.setEchoMode(QtGui.QLineEdit.Password)
        self.login_edit.setFocus()
        self.serv_combo = self.create_list_acc(self.default)

        grid = QtGui.QGridLayout()
        grid.addWidget(login_label, 0, 0)
        grid.addWidget(self.login_edit, 0, 1, 1, 4, QtCore.Qt.AlignLeft)
        grid.addWidget(pasw_label, 1, 0)
        grid.addWidget(self.pasw_edit, 1, 1, 1, 4, QtCore.Qt.AlignLeft)
        service_label = QtGui.QLabel(self.tr("Service"), self)
        service_label.setAlignment(QtCore.Qt.AlignLeft)
        grid.addWidget(service_label, 2, 0, 1, 4, QtCore.Qt.AlignLeft)	
        if default:
            self.login_edit.setText(self.default.username)
            self.pasw_edit.setText(self.default.passwd)
            self.login_edit.setDisabled(True)
            self.service_edit = QtGui.QLabel(default.get_name(), self)
            self.service_edit.setAlignment(QtCore.Qt.AlignLeft)
            grid.addWidget(service_label, 2, 0, 1, 4, QtCore.Qt.AlignLeft)
            grid.addWidget(self.service_edit, 2, 1, 1, 4, QtCore.Qt.AlignLeft)
            grid.addWidget(self.serv_combo, 3, 0, 1, 4, QtCore.Qt.AlignLeft)
            grid.setRowStretch(3, 2)
        else:
            grid.addWidget(self.serv_combo, 2, 1, 1, 4, QtCore.Qt.AlignLeft)
            grid.setRowStretch(2, 2)
        grid.setColumnStretch(0, 1)
        grid.setColumnStretch(1, 2)
        

        self.hbox_add.addWidget(toolbar)
        self.hbox_add.addLayout(grid)
        self.setLayout(self.hbox_add)


    def create_toolbar(self):
        """
        create profile for "add profile" window
        @return
        """
        file_tool_bar = super(AddProfileWindow, self).create_toolbar()
        if self.default:
            file_tool_bar.addAction(self.del_act)
        file_tool_bar.addAction(self.add_acc)
        return file_tool_bar

    def create_actions(self):
        """ 
        create buttons for toolbar
        @return
        """
        if self.default:
            self.del_act = QtGui.QAction(self.tr("&Delete"), self)
            #self.del_act.setStatusTip(self.tr("Delete account"))
            self.del_act.setIcon(QtGui.QIcon("../data/delete.png"))
            self.connect(self.del_act, QtCore.SIGNAL("activated()"),
                         self.del_account_ui)

        self.add_acc = QtGui.QAction(self.tr("&OK"), self)
        #self.add_acc.setStatusTip(self.tr("Add profile"))
        self.add_acc.setIcon(QtGui.QIcon("../data/ok.png"))
        self.connect(self.add_acc, QtCore.SIGNAL("triggered()"),
                     self.add_account)

        super(AddProfileWindow, self).create_actions()


    def create_list_acc(self, default):
        """
        create list with services or accounts
        @param default = None for adding account or default account for
         manage account
        @return acc_combo pop-up list with accounts or services
        """
        acc_combo = QtGui.QComboBox(self)
        self.accounts2 = []
        if default:
            self.accounts2.append(default)
            if default.path_to_ava:
                acc_combo.addItem(QtGui.QIcon(default.path_to_ava),
                                  default.username)
            else:
                acc_combo.addItem(default.username)

            for acc in main_prof.accounts:
                if not acc == default:
                    self.accounts2.append(acc)
                    if acc.path_to_ava:
                        acc_combo.addItem(QtGui.QIcon(acc.path_to_ava),
                                          acc.username)
                    else:
                        acc_combo.addItem(acc.username)

            self.connect(acc_combo,
                         QtCore.SIGNAL("currentIndexChanged(int)"),
                         self.reload_list)

        else:
            services = dispatcher.get_services()
            for i in services:
                icon = QtGui.QIcon(i.get_icon())
                name = i.get_name()
                acc_combo.addItem(icon, name)

        return acc_combo

    def reload_list(self, number):
        """
        reload page with acounts
        @param number = index of selected items
        @return 
        """
        self.login_edit.setText(self.accounts2[number].username)
        self.pasw_edit.setText(self.accounts2[number].passwd)
        self.service_edit.setText(self.accounts2[number].get_name())
        self.default = self.accounts2[number]


    def add_account(self):
        """
        handler for button OK
        @param 
        @return
        """
        if (self.login_edit.text() == "") or (self.pasw_edit.text() == ""):
            QtGui.QMessageBox.information(self, self.tr("Scribo"),
                               self.tr("Please, fill all  lines!"),
                               QtGui.QMessageBox.Yes)
            return

        if self.default:
            ret = self._edit_account()
        else:
            ret = self._add_new_account()

        if ret:
            main_window.home_window()



    def _edit_account(self):

        acc = type(self.default)()

        acc.username = str(self.login_edit.text())
        acc.passwd = str(self.pasw_edit.text())

        try:
            acc.check_login()
        except WarningExc, exc:
            acc.del_account()
            main_window.show_warning(exc)
            return False

        try:
            self.default.refresh_user_info()
        except WarningExc, exc:
            main_window.show_warning(exc)

        self.default.passwd = str(self.pasw_edit.text())
        self.default.set_default()
        acc.del_account()

        return True


    def del_account_ui(self):
        """
        deleting account 
        @param
        @return 
        """
        ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
                               self.tr("Do you really want delete account?"),
                               QtGui.QMessageBox.Yes,
                               QtGui.QMessageBox.No)
        if (ret == QtGui.QMessageBox.No):
            return
        index = self.serv_combo.currentIndex()
        del_acc = self.accounts2[index]
        #it is last account      
        if (len(self.accounts2) - 1):
            self.accounts2.remove(del_acc)
            if (self.default == del_acc):
                self.default = self.accounts2[0] #first account
                main_prof.def_account = self.default
            del_acc.del_account()
            ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                   self.tr("Account is deleted"),
                                   QtGui.QMessageBox.Yes)

        else:
            #all accounts are deleted
            del_acc.del_account()
        main_window.home_window()


from MainWindow import *
