#!/usr/bin/env python
""" 
 @file: RepeatPost.py
  File is a part of Scribo Project
  Module implements repeating send posts from UI
  @author: Zaiceva Diana <zaiceva@cs.karelia.ru>
  @date: 25.03.2010
"""
import sys
#sys.path.append("./src/services")
sys.path.append("./src/ldm")

from PyQt4 import QtCore
from PyQt4 import QtGui

from MainWindow import main_window
from ToolbarWindow import ToolbarWindow

__author__ = "Diana Zaiceva <zaiceva@cs.karelia.ru>"
__version__ = "$Revision: 0.1 $"
__date__ = "$Date: 2010/03/25 $"
__copyright__ = ""
__license__ = "GPLv2"

class RepeatPost(ToolbarWindow):
    """
    class for window with a tree accounts
    @version  1.0
    @author  Zaiceva Diana <zaiceva@cs.karelia.ru>
    """
    def __init__(self, parent, msg):
        """ 
        initialization "tree of messages" window
        @return
        """
        QtGui.QWidget.__init__(self, parent.centralWidget())
        self.mes = msg
        self.tree_view = self.tree_view_acc()
        super(RepeatPost, self).create_actions()
        title = QtGui.QLabel("Please, choose accounts and groups for sending this post", self)
        title.setAlignment(QtCore.Qt.AlignLeft)
        toolbar = self.create_toolbar()
        self.vbox = QtGui.QVBoxLayout()
        self.hbox = QtGui.QHBoxLayout()
        self.hbox.addWidget(toolbar)
        self.vbox.addWidget(title)
        self.vbox.addWidget(self.tree_view)
        self.hbox.addLayout(self.vbox)
        self.setLayout(self.hbox)


    def create_toolbar(self):
        """
        create toolbar for window
        @return
        """
        file_tool_bar = super(RepeatPost, self).create_toolbar()
        self.send_act = QtGui.QAction(self.tr("&Send"), self)
        self.send_act.setIcon(QtGui.QIcon("../data/ok.png"))
        self.connect(self.send_act, QtCore.SIGNAL("triggered()"), self.send_selected)
        file_tool_bar.addAction(self.send_act)
        return file_tool_bar

    def tree_view_acc(self):
        tree_widget = QtGui.QTreeWidget()
        header = QtCore.QStringList("Service")
        header.append("Logins")
        tree_widget.setHeaderLabels(header)
        tree_widget.setColumnCount(2)
        tree_widget.setSelectionMode(QtGui.QAbstractItemView.MultiSelection)
        accounts = []
        self.all_acc = []
        list_acc = main_prof.accounts
        index = 0
        for acc in list_acc:
            self.all_acc.append(acc)
            path_icon = acc.get_icon()

            login = QtGui.QTreeWidgetItem(tree_widget)
            login.setFlags(login.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable)
            # if user haven't userpic on service, it isn't added. 
            if path_icon:
                login.setIcon(0, QtGui.QIcon(QtCore.QString(path_icon)))
            else:
                login.setIcon(0, QtGui.QIcon())

            login.setText(1, acc.username)
            login.setData(1, QtCore.Qt.CheckStateRole, QtCore.QVariant(QtCore.Qt.Unchecked))

            child_login = QtGui.QTreeWidgetItem(login)

            child_login.setFlags(child_login.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable)
            child_login.setText(1, acc.username)

            child_login.setData(1, QtCore.Qt.CheckStateRole, QtCore.QVariant(QtCore.Qt.Unchecked))
            child_login.setData(0, QtCore.Qt.UserRole, QtCore.QVariant(index))
            index = index + 1

            #if login has group...
            groups = acc.get_journals()
            if groups:
                len_groups = len(groups)
            else:
                len_groups = 0
            for l in xrange(len_groups):
                group_login = QtGui.QTreeWidgetItem(login)
                group_login.setFlags(group_login.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable)
                group_login.setText(1, groups[l].username)
                group_login.setData(1, QtCore.Qt.CheckStateRole,
                                     QtCore.QVariant(QtCore.Qt.Unchecked))
                group_login.setData(0, QtCore.Qt.UserRole, QtCore.QVariant(index))
                self.all_acc.append(groups[l])
                index = index + 1

            accounts.append(login)
        tree_widget.insertTopLevelItems(0, accounts)
        self.connect(tree_widget,
                      QtCore.SIGNAL("itemClicked (QTreeWidgetItem *,int)"), self.click_item)
        return tree_widget

    def click_item(self, item, column):
        select = item.data(1, QtCore.Qt.CheckStateRole).toString().toInt()[0]
        if select == QtCore.Qt.Unchecked:
            item.setData(1, QtCore.Qt.CheckStateRole,
                                     QtCore.QVariant(QtCore.Qt.Checked))
        else:
            item.setData(1, QtCore.Qt.CheckStateRole,
                                     QtCore.QVariant(QtCore.Qt.Unchecked))

    def send_selected(self):
        login_items = self.tree_view.selectedItems()
        flag_send = True
        if login_items:
            for item in login_items:
                msg_copy = self.mes.copy()
                acc = item.parent()

                #select root item
                if not acc:
                    if len(login_items) == 1:
                        QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                                self.tr("Please, choose subitem for sending "),
                                                QtGui.QMessageBox.Yes)
                        return
                    continue
                first_child = acc.child(0)

                index = item.data(0, QtCore.Qt.UserRole).toString().toInt()[0]
                send_journal = self.all_acc[index]
                msg_copy.journal = send_journal

                num_acc = first_child.data(0, QtCore.Qt.UserRole).toString().toInt()[0]
                send_acc = self.all_acc[num_acc]
                try:
                    res = send_acc.send_post(msg_copy)
                except WarningExc, exc:
                    main_window.show_warning(exc)
                    flag_send = False

                msg_copy.del_msg_tree()
        else:
            QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                          self.tr("Please, choose account or group for sending "),
                                          QtGui.QMessageBox.Yes)


        if flag_send:
            ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                                self.tr("Post is sent"),
                                                QtGui.QMessageBox.Yes)
        main_window.home_window()



from AddPost import *
